@@ -130,7 +130,7 @@ func writeDeps(fdDep *os.File, tgts []string) (err error) {
 		if _, errStat := os.Stat(tgt); errStat == nil {
 			err = writeDep(fdDep, tgtDir, tgtRel)
 		} else {
-			trace(CDebug, "ifchange: %s <- %s (unexisting)", fdDep.Name(), tgtRel)
+			trace(CDebug, "ifchange: %s <- %s (non-existing)", fdDep.Name(), tgtRel)
 			fields := []recfile.Field{
 				{Name: "Type", Value: DepTypeIfchange},
 				{Name: "Target", Value: tgtRel},
