@@ -40,6 +40,7 @@ import (
 var (
 	Cwd       string
 	BuildUUID string
+	IsTopRedo bool // is it the top redo instance
 )
 
 func mustSetenv(key, value string) {
@@ -229,6 +230,7 @@ func main() {
 	BuildUUID = os.Getenv(EnvBuildUUID)
 	tgtsWasEmpty := len(tgts) == 0
 	if BuildUUID == "" {
+		IsTopRedo = true
 		raw := new([16]byte)
 		if _, err = io.ReadFull(rand.Reader, raw[:]); err != nil {
 			log.Fatalln(err)
