@@ -362,18 +362,6 @@ func runScript(tgtOrig string, errs chan error, traced bool) error {
 		fdNum++
 	}
 
-	if JSR == nil {
-		// infinite jobs
-		cmd.Env = append(cmd.Env, fmt.Sprintf("%s=NO", EnvJSFd))
-	} else {
-		cmd.ExtraFiles = append(cmd.ExtraFiles, JSR)
-		cmd.ExtraFiles = append(cmd.ExtraFiles, JSW)
-		cmd.Env = append(cmd.Env, fmt.Sprintf(
-			"%s=%d,%d", EnvJSFd, 3+fdNum+0, 3+fdNum+1,
-		))
-		fdNum += 2
-	}
-
 	// Preparing stderr
 	var fdStderr *os.File
 	if StderrKeep {
@@ -396,7 +384,21 @@ func runScript(tgtOrig string, errs chan error, traced bool) error {
 
 	Jobs.Add(1)
 	go func() {
-		jsAcquire(shCtx)
+		jsToken := jsAcquire(shCtx)
+		if JSR == nil {
+			// infinite jobs
+			cmd.Env = append(cmd.Env, fmt.Sprintf("%s=NO", EnvJobs))
+		} else {
+			cmd.ExtraFiles = append(cmd.ExtraFiles, JSR)
+			cmd.ExtraFiles = append(cmd.ExtraFiles, JSW)
+			cmd.Env = append(cmd.Env, fmt.Sprintf(
+				"%s=%s %s%d,%d",
+				MakeFlagsName, MakeFlags, MakeJSArg, 3+fdNum+0, 3+fdNum+1,
+			))
+			fdNum += 2
+			cmd.Env = append(cmd.Env, fmt.Sprintf("%s=%d", EnvJSToken, jsToken))
+		}
+
 		if FdStatus != nil {
 			FdStatus.Write([]byte{StatusRun})
 		}
@@ -421,7 +423,7 @@ func runScript(tgtOrig string, errs chan error, traced bool) error {
 		fdNum++
 
 		defer func() {
-			jsRelease(shCtx)
+			jsRelease(shCtx, jsToken)
 			lockRelease()
 			fdDep.Close()
 			fdStdout.Close()
