@@ -24,7 +24,7 @@ import (
 )
 
 const (
-	Version  = "1.6.0"
+	Version  = "1.7.0"
 	Warranty = `Copyright (C) 2020-2021 Sergey Matveev
 
 This program is free software: you can redistribute it and/or modify
@@ -120,5 +120,6 @@ Additional environment variables:
   REDO_TOP_DIR -- do not search for .do above that directory
                   (it can contain .redo/top as an alternative)
   REDO_INODE_NO_TRUST -- do not trust inode information (except for size)
-                         and always check file's hash`)
+                         and always check file's hash
+  REDO_MAKE -- bmake/gmake/none(default) jobserver protocol compatibility`)
 }
